@@ -1,4 +1,4 @@
-from argparse import ArgumentError
+
 import itertools
 from typing import Callable, List
 from .typing import cast2bytes
@@ -16,7 +16,7 @@ def find(arr: List, predict: Callable) -> any:
     elif c_count == 2:
         x_predict = predict
     else:
-        raise ArgumentError(message=f'invalid param count {c_count}')
+        raise Exception(f'invalid param count {c_count}')
     for index, i in enumerate(arr):
         if x_predict(i, index):
             return i
